# mutwo.core

[![Build Status](https://circleci.com/gh/mutwo-org/mutwo.core.svg?style=shield)](https://circleci.com/gh/mutwo-org/mutwo.core)
[![docs](https://readthedocs.org/projects/docs/badge/?version=latest)](https://mutwo.readthedocs.io/en/latest/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![PyPI version](https://badge.fury.io/py/mutwo.core.svg)](https://badge.fury.io/py/mutwo.core)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

This is the `core` package of the [mutwo ecosystem](https://github.com/mutwo-org/.github/blob/main/profile/README.md).
It mainly implements general purpose event abstractions, parameter base classes and other shared utility functions.
Its independent from specific medias, aesthetics or interfaces and only provides a common base library.
Any mutwo package depends on this core package.

![Mutwo package structure](mutwo-structure.png)
